# Vegan Persimmon Flan
Recipe  by Tilde Thurium

This makes 2 servings. Why did I write a recipe that only makes 2 servings? It was the height of COVID, okay, don't judge me.

*Tools:*
- 2 ramekins
- Blender


*Ingredients*: 
- ½ cup persimmon pulp, strained. This takes 2 average sized fuyu persimmons. If they have seeds, remove them.
- 1 tbsp cornstarch
- ½ tsp agar agar
- 1 tbsp agave nectar, or to taste
- 2 tbsp granulated sugar
- ¼ cup coconut creme
- ½ cup almond milk
- ½ tsp vanilla

## Steps
I tried making caramel with the [Full Of Plants](https://fullofplants.com/easy-vegan-caramel-sauce/) method but it was a pain in the ass and I burned myself.

For this recipe, just put the sugar at the bottom of the cup and it somehow magically turns into sauce. Lifehack! 

Combine the cornstarch with the almond milk and stir it in.

whisk persimmon pulp, milk/cornstarch, agar agar, coconut creme, and agave in a saucepan. Bring to a boil. 

The persimmon pulp got a little congealed, so I mixed it with an immersion blender. But you do you, boo.

Let the persimmon mixture cool a bit, for maybe 5 minutes. Stir in the vanilla. Pour it in to your ramekins or what have you. 

Don’t forget and let it cool to room temperature. Agar agar waits for no man. 

Refrigerate for at least 4 hours, or overnight.

To remove from ramekin, try the hot water bath method (didn’t work for me, maybe the water wasn’t hot enough.) Or just run a knife along the edges of the ramekin and jiggle it out. 
